@@ -27,8 +27,7 @@
 #'
 #' @seealso
 #' \code{\link{taf.bootstrap}} calls \code{\link{download.github}} and
-#' \code{taf.install} to download and install R packages, via
-#' \code{\link{process.bib}}.
+#' \code{taf.install} to download and install R packages.
 #'
 #' \code{\link{clean.library}} selectively removes packages from the local TAF
 #' library.
@@ -76,14 +75,6 @@ taf.install <- function(targz=NULL, lib="bootstrap/library", quiet=FALSE)
     else
     {
       install.packages(tgz, lib=lib, repos=NULL, quiet=quiet)
-      ## Store RemoteSha in DESCRIPTION
-      desc <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), all=TRUE)
-      desc$RemoteSha <- sha
-      write.dcf(desc, file.path(lib, pkg, "DESCRIPTION"))
-      ## Store RemoteSha in package.rds
-      meta <- readRDS(file.path(lib, pkg, "Meta/package.rds"))
-      meta$DESCRIPTION["RemoteSha"] <- sha
-      saveRDS(meta, file.path(lib, pkg, "Meta/package.rds"))
     }
   }
 }
